# This module should be included in ApplicationController (or in any other)
# 
# example:
#   include "BackToRefererAfterForm"
#
module BackToRefererAfterForm 
  def self.included(base)
    # Stores the referer after the new, edit or destroy
    base.before_filter :store_referer, :only => [:new, :edit, :destroy]

    # Destroy the stored referer after redirecting or if any other action is called in the middle
    base.before_filter :destroy_stored_referer, :only => [:index]
  end

  # Stores the http referer into a session variable
  def store_referer
    session[:cud_referer] = request.referer
  end

  # Destroy the stored http referer
  def destroy_stored_referer
    session[:cud_referer]=nil
  end


  # Redirects the browser to the stored referer. If there's no stored referer will fallback to
  # the the target specified in options.
  #
  # Redirecting <tt>:back</tt> using <tt>redirect_to</tt> will redirect to the <strong>action</strong> referer, which 
  # is the form. 
  #
  # Redirecting with <tt>redirect_back_or_to :target</tt> will redirect to the <strong>form</strong> referer if possible.
  # this is userful when calling a form from other controller and want to get back to where you came from after the 
  # update/create/destroy action.
  #
  def redirect_back_or_to(options={},response_status={})
    options=session[:cud_referer] if session && session[:cud_referer]
    redirect_to(options,response_status)
  end
end

